@@ -1,5 +1,5 @@
 /*
- * netlink/version.h	Versioning Information
+ * netlink/version.h	Compile Time Versioning Information
  *
  *	This library is free software; you can redistribute it and/or
  *	modify it under the terms of the GNU Lesser General Public
@@ -12,26 +12,17 @@
 #ifndef NETLINK_VERSION_H_
 #define NETLINK_VERSION_H_
 
-/* Compile Time Versioning Information */
-
-#define LIBNL_STRING "libnl 3.2.25"
-#define LIBNL_VERSION "3.2.25"
+#define LIBNL_STRING "libnl 3.2.3"
+#define LIBNL_VERSION "3.2.3"
 
 #define LIBNL_VER_MAJ		3
 #define LIBNL_VER_MIN		2
-#define LIBNL_VER_MIC		25
+#define LIBNL_VER_MIC		3
 #define LIBNL_VER(maj,min)	((maj) << 8 | (min))
 #define LIBNL_VER_NUM		LIBNL_VER(LIBNL_VER_MAJ, LIBNL_VER_MIN)
 
-#define LIBNL_CURRENT		220
+#define LIBNL_CURRENT		203
 #define LIBNL_REVISION		0
-#define LIBNL_AGE		20
-
-/* Run-time version information */
-
-extern const int        nl_ver_num;
-extern const int        nl_ver_maj;
-extern const int        nl_ver_min;
-extern const int        nl_ver_mic;
+#define LIBNL_AGE		3
 
 #endif
